@@ -1,12 +1,12 @@
-#!/usr/bin/perl
 package Acme::ReturnValue::MakeSite;
 
+# ABSTRACT: generate returnvalues.plix.at
+our $VERSION = '1.004'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
 
-# ABSTRACT: generate returnvalues.plix.at
-
 use Path::Class qw();
 use URI::Escape;
 use Encode qw(from_to);
@@ -365,7 +365,7 @@ Acme::ReturnValue::MakeSite - generate returnvalues.plix.at
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -399,11 +399,11 @@ Generate the start page
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2019 by Thomas Klausner.
+This software is copyright (c) 2013 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
